@@ -17,12 +17,12 @@
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 $Tmp="/tmp/ftpwatch.$$";
+$EMail="hakan\@munin.ub2.lu.se";
+$ConfDir="/home/hakan/.ftpwatch";
 
-use Net::FTP;
-
-#open (PAS, "</etc/passwd");
-while (@pw = getpwent) {
-    ($EMail, $p, $uid, $gid, $name, $dir, $sh)=@pw[0, 1, 2, 3, 5, 7, 8];
+open (PAS, "</etc/passwd");
+while (<PAS>) {
+    ($EMail, $p, $uid, $gid, $name, $dir, $sh)=split (/:/, $_);
 		next unless ($EMail eq $ENV{'USER'} || $EMail eq $ENV{'LOGNAME'});
 
     $ConfDir="$dir/.ftpwatch";
@@ -32,47 +32,25 @@ while (@pw = getpwent) {
     open (C, "<$dir/.ftpwatchrc");    
     while (<C>) {
         if (/^([^:]+):?(.{0,1}):(.+)$/) {
-            $sv=$1; $rc=$2; $dir=$3; $file=undef;
+            $sv=$1; $rc=$2; $dir=$3;
 
-						my $ftp = Net::FTP->new($sv, Debug => 0);
-						if (!$ftp) {print stderr "Connect failed: '$@'\n"; next}
-						if (!$ftp->login) {print stderr "Login failed: '$@'\n"; next}
-						if (!$ftp->cwd($dir))  {
-							if ($dir =~ /^(.*)\/([^\/]+)$/) {
-								$dir=$1; $file=$2;
-								if (!$ftp->cwd($dir))  {
-									print stderr "No such dir: '$dir'\n"; next
-								}
-							} else {
-								print stderr "No such dir: '$dir'\n"; next
-							}
-						}
-
-						
-						open (T, ">$Tmp.2");
-						my @dr;
-            if ($rc eq "R") {@dr=$ftp->dir("-R")}
-						else {
-							if (defined $file) {@dr=$ftp->dir($file)}
-							else {@dr=$ftp->dir}
-						}
-
-						foreach (@dr) {
-							if (/^[\-dl]/ | (/^\// && /:\s*$/) && !/\s+\.\.?\s*$/ && 
-									!/^\-+\-$/) {
-								s/^G//g;
-								print T $_,"\n";
-							}
+            if ($rc eq "R") {$flag="-R ";}
+            open (F, "|/usr/bin/ncftp > $Tmp");
+            print F ("open $sv\ndir $flag$dir\nbye\n");
+            close (F);
+            open (F, "<$Tmp"); open (T, ">$Tmp.2");
+            while (<F>) {
+                if (/^[\-dl]/ | (/^\// && /:\s*$/) && !/\s+\.\.?\s*$/ && 
+!/^\-+\-$/) {
+                    s/^G//g;
+                    print T $_;
+                }
             }
             close (F); close(T);
-						$ftp->quit;
 
-            $cf="$sv$dir$rc"; 
-						if (defined $file) {$cf.="/$file";}
-						$cf=~s/\//_/g; $cf="$ConfDir/$cf";
-
-            system ("diff $cf $Tmp.2 > $Tmp.3");
-            system ("cp $Tmp.2 $cf");
+            $dir =~ s/\//_/g;
+            system ("diff $ConfDir/$sv$dir$rc $Tmp.2 > $Tmp.3");
+            system ("cp $Tmp.2 $ConfDir/$sv$dir$rc");
 
             ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,$atime,
              $mtime,$ctime,$blksize,$blocks) = stat("$Tmp.3");
